# Note: Distances are approximations. The distances of these globular clusters are not 
# known to more precision than the distance to the galaxy itself. So, some random
# variation has been added. This means that the CoreRadius and AbsMag parameters have some
# variation as well, since the calculation for it depends on the distance.
#
# The Radius, CoreRadius, and KingConcentration parameters have been taken from various 
# papers. Since the KingConcentration is the logarithm of the ratio between the tidal and
# core radius, if one has two of the parameters, the third parameter can be calculated.
# However, many of the parameters are still likely complete estimates.
# 
# Sources are listed here, in order of decreasing preference:
# Structural Parameters of Mayall II = G1 in M31
# http://adsabs.harvard.edu/abs/2007MNRAS.376.1621M
# 
# Structural Parameters for Globular Clusters in M31
# http://adsabs.harvard.edu/abs/2013AJ....146...20W
# 
# A Comparison Between the Half-light Radii, Luminosities, and UBV Colors of Globular 
# Clusters in M31 and the Galaxy
# http://adsabs.harvard.edu/abs/2010AJ....140.1043V
# 
# The M31 globular cluster system: ugriz and K-band photometry and structural parameters
# http://adsabs.harvard.edu/abs/2010MNRAS.402..803P
#
# A Hubble Space Telescope/WFPC2 Survey of Bright Young Clusters in M31. III. Structural 
# Parameters
# http://adsabs.harvard.edu/abs/2009AJ....138.1667B
# 
# A Survey of Compact Star Clusters in the S-W Field of the M 31 Disk. Structural 
# Parameters. II
# http://adsabs.harvard.edu/abs/2007BaltA..16..397S
# 
# A Survey of Compact Star Clusters in the South-West Field of the M 31 Disk. Structural 
# Parameters
# http://adsabs.harvard.edu/abs/2006BaltA..15..547S
# 
# M31 Globular Clusters in the Hubble Space Telescope Archive. II. Structural Parameters
# http://adsabs.harvard.edu/abs/2002AJ....123.1937B

Globular "Mayall II:SKHB 1"
{
	RA          	  0.546258  # [hours]
	Dec         	 39.577917  # [degrees]
	Distance    	 2.511e+06  # [ly]
	Radius      	     263.2  # [ly], tidal radius
	CoreRadius  	    0.0035  # [arcmin]
	KingConcentration     2.01  # c = log10(r_t/r_c)
	AbsMag      	   -10.625  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NAME+Mayall+II"
}

Globular "Bol 313:SKHB 36:2MASX J00394456+4052554"
{
	RA          	   0.66238  # [hours]
	Dec         	 40.882069  # [degrees]
	Distance    	 2.622e+06  # [ly]
	Radius      	     141.9  # [ly], tidal radius
	CoreRadius  	    0.0026  # [arcmin]
	KingConcentration     1.85  # c = log10(r_t/r_c)
	AbsMag      	    -9.556  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=2MASX+J00394456%2B4052554"
}

Globular "Bol 315:SKHB 38:2MASX J00394856+4031304"
{
	RA          	  0.663492  # [hours]
	Dec         	 40.525125  # [degrees]
	Distance    	2.5484e+06  # [ly]
	Radius      	     5.253  # [ly], tidal radius
	CoreRadius  	    0.0071  # [arcmin]
	KingConcentration    1.463  # c = log10(r_t/r_c)
	AbsMag      	    -9.384  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=2MASX+J00394856%2B4031304"
}

Globular "Bol 1:SKHB 39:2MASX J00395100+4058104"
{
	RA          	  0.664167  # [hours]
	Dec         	 40.969575  # [degrees]
	Distance    	2.5553e+06  # [ly]
	Radius      	     84.47  # [ly], tidal radius
	CoreRadius  	    0.0054  # [arcmin]
	KingConcentration     1.32  # c = log10(r_t/r_c)
	AbsMag      	     -8.93  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=2MASX+J00395100%2B4058104"
}

Globular "Bol 448:[NVK2008] KW100"
{
	RA          	  0.676813  # [hours]
	Dec         	 40.670903  # [degrees]
	Distance    	2.5774e+06  # [ly]
	Radius      	     0.115  # [ly], tidal radius
	CoreRadius  	    0.0002  # [arcmin]
	KingConcentration    3.552  # c = log10(r_t/r_c)
	AbsMag      	    -9.269  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=%5BNVK2008%5D+KW100"
}

Globular "[HTF2008] H16"
{
	RA          	  0.677169  # [hours]
	Dec         	  39.75831  # [degrees]
	Distance    	2.5733e+06  # [ly]
	Radius      	     296.8  # [ly], tidal radius
	CoreRadius  	     0.025  # [arcmin]
	KingConcentration      1.2  # c = log10(r_t/r_c)
	AbsMag      	    -6.955  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=%5BHTF2008%5D+H16"
}

Globular "Bol 13:SKHB 65:2MASX J00403845+4125241"
{
	RA          	  0.677348  # [hours]
	Dec         	 41.423378  # [degrees]
	Distance    	2.6376e+06  # [ly]
	Radius      	     85.13  # [ly], tidal radius
	CoreRadius  	    0.0207  # [arcmin]
	KingConcentration     0.73  # c = log10(r_t/r_c)
	AbsMag      	    -8.289  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=2MASX+J00403845%2B4125241"
}

Globular "Bol 335:2MASX J00404168+4038281"
{
	RA          	  0.678246  # [hours]
	Dec         	 40.641156  # [degrees]
	Distance    	2.5571e+06  # [ly]
	Radius      	     188.5  # [ly], tidal radius
	CoreRadius  	    0.0096  # [arcmin]
	KingConcentration     1.42  # c = log10(r_t/r_c)
	AbsMag      	    -8.982  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=2MASX+J00404168%2B4038281"
}

Globular "Bol 15:2MASX J00404501+4059561"
{
	RA          	  0.679172  # [hours]
	Dec         	 40.998925  # [degrees]
	Distance    	2.5794e+06  # [ly]
	Radius      	     123.6  # [ly], tidal radius
	CoreRadius  	    0.0077  # [arcmin]
	KingConcentration     1.33  # c = log10(r_t/r_c)
	AbsMag      	     -8.41  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=2MASX+J00404501%2B4059561"
}

Globular "Bol 16:SKHB 66:2MASX J00404516+4122098"
{
	RA          	  0.679213  # [hours]
	Dec         	 41.369403  # [degrees]
	Distance    	2.5831e+06  # [ly]
	Radius      	     96.54  # [ly], tidal radius
	CoreRadius  	    0.0009  # [arcmin]
	KingConcentration     2.14  # c = log10(r_t/r_c)
	AbsMag      	    -6.724  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=2MASX+J00404516%2B4122098"
}

Globular "[NVK2008] KW125"
{
	RA          	  0.679721  # [hours]
	Dec         	   40.6828  # [degrees]
	Distance    	2.5466e+06  # [ly]
	Radius      	     112.5  # [ly], tidal radius
	CoreRadius  	    0.0008  # [arcmin]
	KingConcentration     2.26  # c = log10(r_t/r_c)
	AbsMag      	    -5.213  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=%5BNVK2008%5D+KW125"
}

Globular "Bol 339:SKHB 77:2MASX J00410067+3955539"
{
	RA          	  0.683519  # [hours]
	Dec         	 39.931656  # [degrees]
	Distance    	  2.55e+06  # [ly]
	Radius      	     99.15  # [ly], tidal radius
	CoreRadius  	    0.0016  # [arcmin]
	KingConcentration     1.91  # c = log10(r_t/r_c)
	AbsMag      	    -8.006  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=2MASX+J00410067%2B3955539"
}

Globular "Bol 23:SKHB 78:[MLV92] 237751"
{
	RA          	  0.683653  # [hours]
	Dec         	 41.229281  # [degrees]
	Distance    	2.5733e+06  # [ly]
	Radius      	     111.5  # [ly], tidal radius
	CoreRadius  	    0.0071  # [arcmin]
	KingConcentration     1.32  # c = log10(r_t/r_c)
	AbsMag      	   -11.865  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=%5BMLV92%5D+237751"
}

Globular "[KLG2007] GC1 19"
{
	RA          	  0.684711  # [hours]
	Dec         	  41.47719  # [degrees]
	Distance    	2.5874e+06  # [ly]
	Radius      	     62.62  # [ly], tidal radius
	CoreRadius  	    0.0013  # [arcmin]
	KingConcentration      1.8  # c = log10(r_t/r_c)
	AbsMag      	    -5.597  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=%5BKLG2007%5D+GC1+19"
}

Globular "Bol 341:SKHB 81:2MASS J00410915+4035528"
{
	RA          	  0.685878  # [hours]
	Dec         	  40.59803  # [degrees]
	Distance    	2.5415e+06  # [ly]
	Radius      	     96.54  # [ly], tidal radius
	CoreRadius  	    0.0027  # [arcmin]
	KingConcentration     1.68  # c = log10(r_t/r_c)
	AbsMag      	    -8.728  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=2MASS+J00410915%2B4035528"
}

Globular "M31GC J004112+410532"
{
	RA          	  0.686733  # [hours]
	Dec         	  41.09133  # [degrees]
	Distance    	2.5776e+06  # [ly]
	Radius      	      16.2  # [ly], tidal radius
	CoreRadius  	    0.0216  # [arcmin]
	KingConcentration    0.814  # c = log10(r_t/r_c)
	AbsMag      	    -8.419  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=M31GC+J004112%2B410532"
}

Globular "[KLG2007] GC1 20"
{
	RA          	  0.687041  # [hours]
	Dec         	  41.16169  # [degrees]
	Distance    	2.5092e+06  # [ly]
	Radius      	     46.31  # [ly], tidal radius
	CoreRadius  	    0.0121  # [arcmin]
	KingConcentration     0.72  # c = log10(r_t/r_c)
	AbsMag      	    -4.751  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=%5BKLG2007%5D+GC1+20"
}

Globular "Bol 26:SKHB 86:2MASX J00411457+4124399"
{
	RA          	  0.687382  # [hours]
	Dec         	 41.411103  # [degrees]
	Distance    	2.5751e+06  # [ly]
	Radius      	     67.51  # [ly], tidal radius
	CoreRadius  	    0.0053  # [arcmin]
	KingConcentration     1.23  # c = log10(r_t/r_c)
	AbsMag      	    -7.507  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=2MASX+J00411457%2B4124399"
}

Globular "[KLG2007] GC1 26"
{
	RA          	  0.690175  # [hours]
	Dec         	  40.60103  # [degrees]
	Distance    	2.5488e+06  # [ly]
	Radius      	     22.83  # [ly], tidal radius
	CoreRadius  	     0.002  # [arcmin]
	KingConcentration     1.18  # c = log10(r_t/r_c)
	AbsMag      	    -6.305  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=%5BKLG2007%5D+GC1+26"
}

Globular "Bol 36:2MASS J00413283+4126051"
{
	RA          	  0.692453  # [hours]
	Dec         	  41.43478  # [degrees]
	Distance    	2.5549e+06  # [ly]
	Radius      	     70.78  # [ly], tidal radius
	CoreRadius  	    0.0029  # [arcmin]
	KingConcentration     1.52  # c = log10(r_t/r_c)
	AbsMag      	     -8.24  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=2MASS+J00413283%2B4126051"
}

Globular "Bol 40:SKHB 102:[NVK2008] KW284"
{
	RA          	   0.69412  # [hours]
	Dec         	 40.681811  # [degrees]
	Distance    	2.5442e+06  # [ly]
	Radius      	     2.401  # [ly], tidal radius
	CoreRadius  	    0.0032  # [arcmin]
	KingConcentration    2.473  # c = log10(r_t/r_c)
	AbsMag      	    -9.501  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=%5BNVK2008%5D+KW284"
}

Globular "[KLG2007] GC1 35"
{
	RA          	  0.696467  # [hours]
	Dec         	  41.87619  # [degrees]
	Distance    	2.6018e+06  # [ly]
	Radius      	      69.8  # [ly], tidal radius
	CoreRadius  	    0.0033  # [arcmin]
	KingConcentration     1.45  # c = log10(r_t/r_c)
	AbsMag      	    -9.639  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=%5BKLG2007%5D+GC1+35"
}

Globular "Bol 58:SKHB 119:2MASS J00415300+4047096"
{
	RA          	  0.698058  # [hours]
	Dec         	  40.78603  # [degrees]
	Distance    	2.5207e+06  # [ly]
	Radius      	     86.43  # [ly], tidal radius
	CoreRadius  	    0.0021  # [arcmin]
	KingConcentration     1.59  # c = log10(r_t/r_c)
	AbsMag      	     -9.47  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=2MASS+J00415300%2B4047096"
}

Globular "Bol 82:SKHB 144:2MASS J00421583+4101142"
{
	RA          	    0.7044  # [hours]
	Dec         	  41.02064  # [degrees]
	Distance    	2.5192e+06  # [ly]
	Radius      	     88.06  # [ly], tidal radius
	CoreRadius  	     0.002  # [arcmin]
	KingConcentration     1.77  # c = log10(r_t/r_c)
	AbsMag      	   -10.999  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=2MASS+J00421583%2B4101142"
}

Globular "Bol 94:SKHB 156:2MASS J00422504+4057176"
{
	RA          	  0.706955  # [hours]
	Dec         	  40.95489  # [degrees]
	Distance    	2.5176e+06  # [ly]
	Radius      	     76.97  # [ly], tidal radius
	CoreRadius  	    0.0018  # [arcmin]
	KingConcentration     1.77  # c = log10(r_t/r_c)
	AbsMag      	    -9.518  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=2MASS+J00422504%2B4057176"
}

Globular "Bol 98:2MASS J00422739+4059358"
{
	RA          	  0.707608  # [hours]
	Dec         	  40.99331  # [degrees]
	Distance    	2.5597e+06  # [ly]
	Radius      	     45.34  # [ly], tidal radius
	CoreRadius  	    0.0018  # [arcmin]
	KingConcentration     1.52  # c = log10(r_t/r_c)
	AbsMag      	    -8.904  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=2MASS+J00422739%2B4059358"
}

Globular "Bol 110:SKHB 172:2MASS J00423310+4103283"
{
	RA          	  0.709195  # [hours]
	Dec         	  41.05789  # [degrees]
	Distance    	2.5033e+06  # [ly]
	Radius      	     66.21  # [ly], tidal radius
	CoreRadius  	    0.0019  # [arcmin]
	KingConcentration     1.44  # c = log10(r_t/r_c)
	AbsMag      	    -9.145  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=2MASS+J00423310%2B4103283"
}

Globular "M31GC J004233+412017"
{
	RA          	    0.7092  # [hours]
	Dec         	    41.338  # [degrees]
	Distance    	2.5441e+06  # [ly]
	Radius      	     1.152  # [ly], tidal radius
	CoreRadius  	    0.0016  # [arcmin]
	KingConcentration    1.752  # c = log10(r_t/r_c)
	AbsMag      	    -7.041  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=M31GC+J004233%2B412017"
}

Globular "[KLG2007] GC1 52"
{
	RA          	  0.710367  # [hours]
	Dec         	  41.84822  # [degrees]
	Distance    	2.5616e+06  # [ly]
	Radius      	     44.68  # [ly], tidal radius
	CoreRadius  	    0.0072  # [arcmin]
	KingConcentration     0.92  # c = log10(r_t/r_c)
	AbsMag      	    -7.115  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=%5BKLG2007%5D+GC1+52"
}

Globular "[KLG2007] GC1 53"
{
	RA          	  0.711336  # [hours]
	Dec         	    40.298  # [degrees]
	Distance    	2.5732e+06  # [ly]
	Radius      	       107  # [ly], tidal radius
	CoreRadius  	    0.0007  # [arcmin]
	KingConcentration     2.34  # c = log10(r_t/r_c)
	AbsMag      	    -7.775  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=%5BKLG2007%5D+GC1+53"
}

Globular "M31GC J004243+402927"
{
	RA          	  0.711811  # [hours]
	Dec         	  40.49078  # [degrees]
	Distance    	2.5268e+06  # [ly]
	Radius      	     23.81  # [ly], tidal radius
	CoreRadius  	    0.0074  # [arcmin]
	KingConcentration     0.64  # c = log10(r_t/r_c)
	AbsMag      	    -6.576  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=M31GC+J004243%2B402927"
}

Globular "[KLG2007] GC1 55"
{
	RA          	  0.714405  # [hours]
	Dec         	  40.73608  # [degrees]
	Distance    	2.6352e+06  # [ly]
	Radius      	     98.83  # [ly], tidal radius
	CoreRadius  	    0.0107  # [arcmin]
	KingConcentration     1.08  # c = log10(r_t/r_c)
	AbsMag      	    -8.257  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=%5BKLG2007%5D+GC1+55"
}

Globular "Bol 168:2MASX J00432253+4144058"
{
	RA          	  0.722926  # [hours]
	Dec         	 41.734956  # [degrees]
	Distance    	2.5238e+06  # [ly]
	Radius      	     94.26  # [ly], tidal radius
	CoreRadius  	    0.0018  # [arcmin]
	KingConcentration     1.86  # c = log10(r_t/r_c)
	AbsMag      	    -9.943  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=2MASX+J00432253%2B4144058"
}

Globular "[KLG2007] GC1 66"
{
	RA          	  0.723355  # [hours]
	Dec         	  41.64508  # [degrees]
	Distance    	2.5504e+06  # [ly]
	Radius      	     105.7  # [ly], tidal radius
	CoreRadius  	    0.0006  # [arcmin]
	KingConcentration     2.36  # c = log10(r_t/r_c)
	AbsMag      	    -4.916  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=%5BKLG2007%5D+GC1+66"
}

Globular "Bol 176:SKHB 227:2MASX J00433041+4049108"
{
	RA          	  0.725114  # [hours]
	Dec         	 40.819683  # [degrees]
	Distance    	2.6008e+06  # [ly]
	Radius      	     249.8  # [ly], tidal radius
	CoreRadius  	    0.0059  # [arcmin]
	KingConcentration     1.75  # c = log10(r_t/r_c)
	AbsMag      	    -8.578  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=2MASX+J00433041%2B4049108"
}

Globular "Bol 193:SKHB 244:2MASX J00434551+4136578"
{
	RA          	  0.729309  # [hours]
	Dec         	 41.616067  # [degrees]
	Distance    	2.5721e+06  # [ly]
	Radius      	     85.45  # [ly], tidal radius
	CoreRadius  	    0.0016  # [arcmin]
	KingConcentration     1.86  # c = log10(r_t/r_c)
	AbsMag      	    -9.634  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=2MASX+J00434551%2B4136578"
}

Globular "[KLG2007] GC1 71"
{
	RA          	  0.729558  # [hours]
	Dec         	  41.65794  # [degrees]
	Distance    	2.5152e+06  # [ly]
	Radius      	     73.71  # [ly], tidal radius
	CoreRadius  	    0.0086  # [arcmin]
	KingConcentration     1.07  # c = log10(r_t/r_c)
	AbsMag      	    -4.366  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=%5BKLG2007%5D+GC1+71"
}

Globular "Bol 196:SKHB 246:2MASS J00434857+4042368"
{
	RA          	  0.730158  # [hours]
	Dec         	  40.71025  # [degrees]
	Distance    	2.5843e+06  # [ly]
	Radius      	     97.52  # [ly], tidal radius
	CoreRadius  	    0.0049  # [arcmin]
	KingConcentration     1.42  # c = log10(r_t/r_c)
	AbsMag      	    -8.315  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=2MASS+J00434857%2B4042368"
}

Globular "M31GC J004401+411713"
{
	RA          	  0.733567  # [hours]
	Dec         	  41.28678  # [degrees]
	Distance    	2.5732e+06  # [ly]
	Radius      	     80.23  # [ly], tidal radius
	CoreRadius  	    0.0055  # [arcmin]
	KingConcentration     1.29  # c = log10(r_t/r_c)
	AbsMag      	    -7.575  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=M31GC+J004401%2B411713"
}

Globular "SKHB 260:M31GC J004401+423447"
{
	RA          	  0.733567  # [hours]
	Dec         	  42.58008  # [degrees]
	Distance    	2.5679e+06  # [ly]
	Radius      	     168.6  # [ly], tidal radius
	CoreRadius  	    0.0059  # [arcmin]
	KingConcentration     1.58  # c = log10(r_t/r_c)
	AbsMag      	    -8.021  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=M31GC+J004401%2B423447"
}

Globular "SKHB 268:2MASX J00440998+4246578"
{
	RA          	  0.736106  # [hours]
	Dec         	 42.782733  # [degrees]
	Distance    	2.5716e+06  # [ly]
	Radius      	     113.8  # [ly], tidal radius
	CoreRadius  	    0.0073  # [arcmin]
	KingConcentration     1.32  # c = log10(r_t/r_c)
	AbsMag      	    -8.684  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=2MASX+J00440998%2B4246578"
}

Globular "[KLG2007] GC1 83"
{
	RA          	  0.736108  # [hours]
	Dec         	  41.85794  # [degrees]
	Distance    	2.5164e+06  # [ly]
	Radius      	     65.23  # [ly], tidal radius
	CoreRadius  	    0.0004  # [arcmin]
	KingConcentration     2.34  # c = log10(r_t/r_c)
	AbsMag      	    -8.017  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=%5BKLG2007%5D+GC1+83"
}

Globular "Bol 219:SKHB 271:2MASX J00441503+4056469"
{
	RA          	  0.737508  # [hours]
	Dec         	 40.946372  # [degrees]
	Distance    	2.5705e+06  # [ly]
	Radius      	     87.41  # [ly], tidal radius
	CoreRadius  	    0.0024  # [arcmin]
	KingConcentration     1.68  # c = log10(r_t/r_c)
	AbsMag      	    -8.783  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=2MASX+J00441503%2B4056469"
}

Globular "Bol 221:SKHB 276:2MASX J00442305+4133065"
{
	RA          	  0.739737  # [hours]
	Dec         	 41.551806  # [degrees]
	Distance    	2.5568e+06  # [ly]
	Radius      	     75.02  # [ly], tidal radius
	CoreRadius  	    0.0047  # [arcmin]
	KingConcentration     1.33  # c = log10(r_t/r_c)
	AbsMag      	    -8.651  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=2MASX+J00442305%2B4133065"
}

Globular "[KLG2007] GC1 86"
{
	RA          	  0.740575  # [hours]
	Dec         	  41.58733  # [degrees]
	Distance    	2.6314e+06  # [ly]
	Radius      	     112.5  # [ly], tidal radius
	CoreRadius  	    0.0134  # [arcmin]
	KingConcentration     1.04  # c = log10(r_t/r_c)
	AbsMag      	    -5.654  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=%5BKLG2007%5D+GC1+86"
}

Globular "Bol 235:SKHB 297:2MASX J00445796+4129235"
{
	RA          	  0.749434  # [hours]
	Dec         	 41.489875  # [degrees]
	Distance    	2.5587e+06  # [ly]
	Radius      	     88.71  # [ly], tidal radius
	CoreRadius  	    0.0018  # [arcmin]
	KingConcentration     1.81  # c = log10(r_t/r_c)
	AbsMag      	    -8.933  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=2MASX+J00445796%2B4129235"
}

Globular "Bol 370:SKHB 300:2MASX J00451437+4157405"
{
	RA          	  0.753993  # [hours]
	Dec         	 41.961278  # [degrees]
	Distance    	2.6309e+06  # [ly]
	Radius      	     115.1  # [ly], tidal radius
	CoreRadius  	    0.0021  # [arcmin]
	KingConcentration     1.85  # c = log10(r_t/r_c)
	AbsMag      	    -9.483  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=2MASX+J00451437%2B4157405"
}

Globular "Bol 372:SKHB 304:2MASX J00453337+4200243"
{
	RA          	  0.759272  # [hours]
	Dec         	 42.006753  # [degrees]
	Distance    	2.5695e+06  # [ly]
	Radius      	     123.6  # [ly], tidal radius
	CoreRadius  	    0.0056  # [arcmin]
	KingConcentration     1.47  # c = log10(r_t/r_c)
	AbsMag      	    -8.912  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=2MASX+J00453337%2B4200243"
}

Globular "[KLG2007] GC1 104"
{
	RA          	  0.762309  # [hours]
	Dec         	  41.95772  # [degrees]
	Distance    	2.5437e+06  # [ly]
	Radius      	     50.23  # [ly], tidal radius
	CoreRadius  	    0.0031  # [arcmin]
	KingConcentration     1.34  # c = log10(r_t/r_c)
	AbsMag      	     -7.72  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=%5BKLG2007%5D+GC1+104"
}

Globular "Bol 393:SKHB 330:2MASX J00470122+4124067"
{
	RA          	  0.783674  # [hours]
	Dec         	 41.401881  # [degrees]
	Distance    	 2.546e+06  # [ly]
	Radius      	     136.3  # [ly], tidal radius
	CoreRadius  	    0.0097  # [arcmin]
	KingConcentration     1.28  # c = log10(r_t/r_c)
	AbsMag      	    -8.402  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=2MASX+J00470122%2B4124067"
}

Globular "[KLG2007] GC1 109"
{
	RA          	  0.788014  # [hours]
	Dec         	  41.05325  # [degrees]
	Distance    	2.5439e+06  # [ly]
	Radius      	     186.6  # [ly], tidal radius
	CoreRadius  	    0.0035  # [arcmin]
	KingConcentration     1.86  # c = log10(r_t/r_c)
	AbsMag      	     -7.02  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=%5BKLG2007%5D+GC1+109"
}

Globular "Bol 402:SKHB 346:2MASX J00483604+4201350"
{
	RA          	  0.810013  # [hours]
	Dec         	 42.026397  # [degrees]
	Distance    	2.5436e+06  # [ly]
	Radius      	     68.17  # [ly], tidal radius
	CoreRadius  	    0.0103  # [arcmin]
	KingConcentration     0.95  # c = log10(r_t/r_c)
	AbsMag      	     -8.14  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=2MASX+J00483604%2B4201350"
}
